akhdefo_functions.stackprep — akhdefo 2023 documentation

# akhdefo_functions.stackprep

akhdefo_functions.stackprep(path_to_flowxnFolder='', path_toFlowynFolder='', dem='', print_list=False, start_date='YYYYMMDD', end_date='YYYYMMDD', output_stackedFolder='', VEL_scale=('month', 'year'), xres=3.125, yres=3.125, Velocity_shapeFile=False, Resampling=True)

  This program collects velocity candiate points for time-series analysis

  path_to_flowxnFolder=r”” path to folder include east-west velocity files

  path_toFlowynFolder=r”” path to folder include north-south velocity files

  dem=r”” path to digital elevation model file will be used to geocode the products

  print_list=False print list of temporal proceesed dates default is False

  start_date=”YYYYMMDD”

  end_date=”YYYYMMDD”

  output_stackedFolder=r””

  VEL_scale=(“month”,”year”)

  xres=3.125, yres=3.125

  Velocity_shapeFile=False set to True if need to generate points for temporal deformation analysis

  Resampling=True if True reduce number of measurement points but faster processing